Function cwe_checker_lib::analysis::backward_interprocedural_fixpoint::create_computation_with_bottom_up_worklist_order
source · pub fn create_computation_with_bottom_up_worklist_order<'a, T: Context<'a>>(
problem: T,
default_value: Option<T::Value>
) -> Computation<GeneralizedContext<'a, T>>Expand description
Generate a new computation from the corresponding context and an optional default value for nodes. Uses a bottom up worklist order when computing the fixpoint.
The worklist order prefers callee nodes before caller nodes.